==> SnareCoreVista-0.3.zip: SnareCoreVista-0.3/WebPages.h <==
int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size,SOCKET http_socket, HANDLE event);

int		Status_Page(char *source, char *dest, int size);
int		Current_Events(char *source, char *dest, int size);
int		DefaultHeader(char *source, char *dest, int size, int refreshflag=0);
int		Network_Config(char *source, char *dest, int size);
int		Remote_Config(char *source, char *dest, int size);
int		Remote_Set(char *source, char *dest, int size);
int		Objective_Config(char *source, char *dest, int size);
int		DefaultFooter(char *source, char *dest, int size);

int		InterSectImage(char *source, char *dest, int size);
int		InterSectImageCrit(char *source, char *dest, int size);
int		InterSectImagePri(char *source, char *dest, int size);
int		InterSectImageWarn(char *source, char *dest, int size);
int		InterSectImageInfo(char *source, char *dest, int size);
int		InterSectImageClear(char *source, char *dest, int size);
int		Objective_Display(char *source, char *dest, int size);
int		Restart(char *source, char *dest, int size, HANDLE event);
int		Network_Set(char *source, char *dest, int size);
int		Objective_Result(char *, char *, int);

extern int     ReadObjectives();
extern void    DestroyList(void);
int		debracket(char *source, char *dest, int length);

int		ShowLocalUsers(SOCKET http_socket);
int		ShowDomainUsers(SOCKET http_socket);

int		ShowLocalGroupMembers(SOCKET http_socket);
int		ShowThisLocalGroupMembers(WCHAR *Group,SOCKET http_socket);

int		ShowDomainGroupMembers(SOCKET http_socket);
int		ShowThisDomainGroupMembersNT(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);
int		ShowDomainUserGroupsWin2k(SOCKET http_socket);

int		DumpConfig(SOCKET http_socket);

// HRESULT TestEnumObject( LPWSTR pszADsPath );

int		DumpRegistry(SOCKET http_socket, char *source, char * Output, int OutputSize);
int		RegDump(HKEY key, char * rootname, char *path, SOCKET http_socket);

BOOL	ADIsMixedMode(void);

// Stuff we use from webserver.h
int		base64decode(char *dest, char *src);
char *	GetNextArgument(char *source,char *destvar,int varlength,char *destval,int vallength);

int		DisplayTextHeader(SOCKET http_socket);
int		Display404(SOCKET http_socket);

BOOL	GetUserSid(LPTSTR szName,LPTSTR TextualSid,LPDWORD lpdwBufferLen);

==> SnareCoreVista-1.0.zip: SnareCoreVista-1.0/WebPages.h <==
int		HandleWebPages(char *HTTPBuffer,char *HTTPOutputBuffer,int size,SOCKET http_socket, HANDLE event);

int		Status_Page(char *source, char *dest, int size);
int		Current_Events(char *source, char *dest, int size);
int		DefaultHeader(char *source, char *dest, int size, int refreshflag=0);
int		Network_Config(char *source, char *dest, int size);
int		Remote_Config(char *source, char *dest, int size);
int		Remote_Set(char *source, char *dest, int size);
int		Objective_Config(char *source, char *dest, int size);
int		DefaultFooter(char *source, char *dest, int size);

int		InterSectImage(char *source, char *dest, int size);
int		InterSectImageCrit(char *source, char *dest, int size);
int		InterSectImagePri(char *source, char *dest, int size);
int		InterSectImageWarn(char *source, char *dest, int size);
int		InterSectImageInfo(char *source, char *dest, int size);
int		InterSectImageClear(char *source, char *dest, int size);
int		Objective_Display(char *source, char *dest, int size);
int		Restart(char *source, char *dest, int size, HANDLE event);
int		Network_Set(char *source, char *dest, int size);
int		Objective_Result(char *, char *, int);

extern int     ReadObjectives();
extern void    DestroyList(void);
int		debracket(char *source, char *dest, int length);

int		ShowLocalUsers(SOCKET http_socket);
int		ShowDomainUsers(SOCKET http_socket);

int		ShowLocalGroupMembers(SOCKET http_socket);
int		ShowThisLocalGroupMembers(WCHAR *Group,SOCKET http_socket);

int		ShowDomainGroupMembers(SOCKET http_socket);
int		ShowThisDomainGroupMembersNT(WCHAR *Group,WCHAR *PDC,SOCKET http_socket);
int		ShowDomainUserGroupsWin2k(SOCKET http_socket);

int		GetConfig(SOCKET http_socket);
int		SetConfig(char *source, SOCKET http_socket);


// HRESULT TestEnumObject( LPWSTR pszADsPath );

int		DumpRegistry(SOCKET http_socket, char *source, char * Output, int OutputSize);
int		RegDump(HKEY key, char * rootname, char *path, SOCKET http_socket);

BOOL	ADIsMixedMode(void);

// Stuff we use from webserver.h
int		base64decode(char *dest, char *src);
char *	GetNextArgument(char *source,char *destvar,int varlength,char *destval,int vallength);

int		DisplayTextHeader(SOCKET http_socket);
int		Display404(SOCKET http_socket);

BOOL	GetUserSid(LPTSTR szName,LPTSTR TextualSid,LPDWORD lpdwBufferLen);
